Tree Density Calculator
-----------------------

The *Tree Density Calculator* is a QGIS plugin and command line interface package designed to calculate tree densities.

The original Tree Density Calculator was written in C++ and ported to PyQGIS in 2018/2019. It has been developed in the
open source environment to encourage further development of the tool.

The **instruction pages** can be found at https://localmaxfilter.readthedocs.io and include guidance for installation,
a user manual, exercises and an API.

The **repository** and **testdata** can be found at https://bitbucket.org/kul-reseco/localmaxfilter.

Referencing the Tree Density Calculator
---------------------------------------

When using the Tree Density Calculator, please use the following citation:

Crabbé, A. H., Cahy, T., Put, L., Somers, B., Verbeke, L.P., Van Coillie, F. (2019). Tree Density Calculator Software
(Version x.x) [Software]. Available from https://bitbucket.org/kul-reseco/localmaxfilter.

**Acknowledgements**

The software and user guide are based on the Local Maximum Filter [C++ software]:
Ghent University, Laboratory of Forest Management and Spatial Information Techniques, Lieven P.C. Verbeke

The revision into a QGIS plugin is funded primarily through BELSPO (the Belgian Science Policy Office) in the framework
of the STEREO III Programme – Project LUMOS - SR/01/321.

The LUMOS logo was created for free at https://logomakr.com.

**Software Licence**

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General
Public License as published by the Free Software Foundation; either version 3 of the License, or any later version.

